package com.ruoyi.system.service;

import com.ruoyi.system.domain.QyWordtemplate;
import java.util.List;

/**
 * word文件表Service接口
 * 
 * @author ruoyi
 * @date 2019-09-10
 */
public interface IQyWordtemplateService 
{
    /**
     * 查询word文件表
     * 
     * @param id word文件表ID
     * @return word文件表
     */
    QyWordtemplate selectQyWordtemplateById(Long id);

    /**
     * 查询word文件表列表
     * 
     * @param qyWordtemplate word文件表
     * @return word文件表集合
     */
    List<QyWordtemplate> selectQyWordtemplateList(QyWordtemplate qyWordtemplate);

    /**
     * 新增word文件表
     * 
     * @param qyWordtemplate word文件表
     * @return 结果
     */
    int insertQyWordtemplate(QyWordtemplate qyWordtemplate);

    /**
     * 修改word文件表
     * 
     * @param qyWordtemplate word文件表
     * @return 结果
     */
    int updateQyWordtemplate(QyWordtemplate qyWordtemplate);

    /**
     * 批量删除word文件表
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    int deleteQyWordtemplateByIds(String ids);

    /**
     * 删除word文件表信息
     * 
     * @param id word文件表ID
     * @return 结果
     */
    int deleteQyWordtemplateById(Long id);
}
